@@ -18,9 +18,10 @@ $state->{version} = $stateversion;
 
 $::config = $state->{config} ||= {};
 
-$::config->{speed}           = 0; #d# optimize for speed or memory? (0,1)
-$::config->{conserve_memory} = 0; # try to conserve memory at the expense of speed (0,1,2)
-$::config->{randomize}       = 0; # randomize placement of stones (BROKEN)
+$::config->{speed}            = 0; #d# optimize for speed or memory? (0,1)
+$::config->{conserve_memory}  = 0; # try to conserve memory at the expense of speed (0,1,2)
+$::config->{randomize}        = 0; # randomize placement of stones (BROKEN)
+$::config->{suppress_userpic} = 0; # for omitting the userpic in the game window
 
 sub save_config {
    &gtk::save_state;
@@ -36,6 +37,12 @@ sub format_time($) {
       : sprintf      "%d:%02d", $time / 60 % 60, $time % 60;
 }
 
+sub date_string($) {
+  my ($timestamp) = @_;
+  use POSIX ();
+  return (POSIX::strftime "%Y-%m-%d %H:%M", localtime $timestamp);
+}
+
 sub parse_time($) {
 
    my $time;
