@@ -63,19 +63,19 @@ sub new {
 =item $listener->listen ($conn, [msgtype...])
 
 Registers the object to receive callback messages of the named type(s).
+If C<$conn> is C<undef>, returns immediately. It's safe to call this
+function repeatedly.
 
 A msgtype is either a packet name like C<login> or C<msg_room>, the
 string C<any>, which will match any type, or a msgtype postdixed with
 C<:> (e.g. C<msg_room:>), in which case it will only match the C<<
 $listener->{channel} >> channel.
 
-The conenction will be stored in C<< $listener->{conn} >>.
+The connection will be stored in C<< $listener->{conn} >>.
 
 In your own new method you should call C<< $self->listen >> once with the
 connection and the msgtypes you want to listen for.
 
-Calling C<listen> multiple times is valid and will works incrementally.
-
 =item $listener->unlisten
 
 Unregisters the object again.
@@ -85,21 +85,20 @@ Unregisters the object again.
 sub listen {
    my ($self, $conn, @types) = @_;
 
-   $_ =~ s/:$/:$self->{channel}/ for @types;
-
    if ($conn) {
       $self->unlisten;
       $self->{conn} = $conn;
+      $_ =~ s/:$/:$self->{channel}/ for @types;
       $self->{listen_types} = \@types;
-      $conn->register($self, @types);
+      $self->{conn}->register ($self, "quit", @types);
    }
 }
 
 sub unlisten {
    my ($self) = @_;
 
-   (delete $self->{conn})
-      ->unregister ($self, @{$self->{listen_types}}) if $self->{conn};
+   (delete $self->{conn})->unregister ($self, @{$self->{listen_types}})
+      if $self->{conn};
 }
 
 =item $listener->inject ($msg)
@@ -115,16 +114,16 @@ methods that are being called with names like C<inject_msg_room> etc.
 sub inject {
    my ($self, $msg) = @_;
 
-   if (my $cb = $self->can("inject_$msg->{type}")) {
+   if (my $cb = $self->can ("inject_$msg->{type}")) {
       $cb->($self, $msg);
-   } elsif (my $cb = $self->can("inject_any")) {
+   } elsif (my $cb = $self->can ("inject_any")) {
       $cb->($self, $msg);
    } else {
       warn "no handler found for message $msg->{type} in $self\n";
    }
 }
 
-=item $listener->send($type, %args);
+=item $listener->send ($type, %args);
 
 Calls the C<send> method of the connection when in listen state. It does
 not (yet) supply a default channel id.
@@ -134,7 +133,19 @@ not (yet) supply a default channel id.
 sub send {
    my ($self, $type, @arg) = @_;
 
-   $self->{conn}->send($type, @arg) if $self->{conn};
+   $self->{conn}->send ($type, @arg) if $self->{conn};
+}
+
+sub inject_quit {
+   my ($self) = @_;
+
+   $self->event_quit;
+}
+
+sub event_quit {
+   my ($self) = @_;
+
+   $self->unlisten;
 }
 
 sub DESTROY {
